==> cloudformation-1.60.0-sources.jar: software/amazon/awscdk/services/cloudformation/CustomResource.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * Deprecated.
 * <p>
 * @deprecated use `core.CustomResource`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.361Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CustomResource")
public class CustomResource extends software.amazon.awscdk.core.CustomResource {

    protected CustomResource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CustomResource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public CustomResource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudformation.CustomResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cloudformation.CustomResource}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cloudformation.CustomResource> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.cloudformation.CustomResourceProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.cloudformation.CustomResourceProps.Builder();
        }

        /**
         * The provider which implements the custom resource.
         * <p>
         * You can implement a provider by listening to raw AWS CloudFormation events
         * through an SNS topic or an AWS Lambda function or use the CDK's custom
         * <a href="https://docs.aws.amazon.com/cdk/api/latest/docs/custom-resources-readme.html">resource provider framework</a> which makes it easier to implement robust
         * providers.
         * <p>
         * <blockquote><pre>
         * // Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
         * provider: new custom_resources.Provider({
         *    onEventHandler: myOnEventLambda,
         *    isCompleteHandler: myIsCompleteLambda, // optional
         * });
         * </pre></blockquote>
         * <p>
         * <blockquote><pre>
         * // Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
         * provider: CustomResourceProvider.fromLambda(myFunction)
         * </pre></blockquote>
         * <p>
         * <blockquote><pre>
         * // Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
         * provider: CustomResourceProvider.fromTopic(myTopic)
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param provider The provider which implements the custom resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder provider(final software.amazon.awscdk.services.cloudformation.ICustomResourceProvider provider) {
            this.props.provider(provider);
            return this;
        }

        /**
         * Properties to pass to the Lambda.
         * <p>
         * Default: - No properties.
         * <p>
         * @return {@code this}
         * @param properties Properties to pass to the Lambda. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder properties(final java.util.Map<java.lang.String, java.lang.Object> properties) {
            this.props.properties(properties);
            return this;
        }

        /**
         * The policy to apply when this resource is removed from the application.
         * <p>
         * Default: cdk.RemovalPolicy.Destroy
         * <p>
         * @return {@code this}
         * @param removalPolicy The policy to apply when this resource is removed from the application. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder removalPolicy(final software.amazon.awscdk.core.RemovalPolicy removalPolicy) {
            this.props.removalPolicy(removalPolicy);
            return this;
        }

        /**
         * For custom resources, you can specify AWS::CloudFormation::CustomResource (the default) as the resource type, or you can specify your own resource type name.
         * <p>
         * For example, you can use "Custom::MyCustomResourceTypeName".
         * <p>
         * Custom resource type names must begin with "Custom::" and can include
         * alphanumeric characters and the following characters: _&#64;-. You can specify
         * a custom resource type name up to a maximum length of 60 characters. You
         * cannot change the type during an update.
         * <p>
         * Using your own resource type names helps you quickly differentiate the
         * types of custom resources in your stack. For example, if you had two custom
         * resources that conduct two different ping tests, you could name their type
         * as Custom::PingTester to make them easily identifiable as ping testers
         * (instead of using AWS::CloudFormation::CustomResource).
         * <p>
         * Default: - AWS::CloudFormation::CustomResource
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cfn-customresource.html#aws-cfn-resource-type-name
         * @param resourceType For custom resources, you can specify AWS::CloudFormation::CustomResource (the default) as the resource type, or you can specify your own resource type name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder resourceType(final java.lang.String resourceType) {
            this.props.resourceType(resourceType);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cloudformation.CustomResource}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.cloudformation.CustomResource build() {
            return new software.amazon.awscdk.services.cloudformation.CustomResource(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> cloudformation-1.104.0-sources.jar: software/amazon/awscdk/services/cloudformation/CustomResource.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * (deprecated) Deprecated.
 * <p>
 * @deprecated use `core.CustomResource`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:08.328Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CustomResource")
public class CustomResource extends software.amazon.awscdk.core.CustomResource {

    protected CustomResource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CustomResource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public CustomResource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudformation.CustomResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.cloudformation.CustomResource}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cloudformation.CustomResource> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.cloudformation.CustomResourceProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.cloudformation.CustomResourceProps.Builder();
        }

        /**
         * (deprecated) The provider which implements the custom resource.
         * <p>
         * You can implement a provider by listening to raw AWS CloudFormation events
         * through an SNS topic or an AWS Lambda function or use the CDK's custom
         * <a href="https://docs.aws.amazon.com/cdk/api/latest/docs/custom-resources-readme.html">resource provider framework</a> which makes it easier to implement robust
         * providers.
         * <p>
         * <blockquote><pre>
         * // Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
         * provider: new custom_resources.Provider({
         *    onEventHandler: myOnEventLambda,
         *    isCompleteHandler: myIsCompleteLambda, // optional
         * });
         * </pre></blockquote>
         * <p>
         * <blockquote><pre>
         * // Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
         * provider: CustomResourceProvider.fromLambda(myFunction)
         * </pre></blockquote>
         * <p>
         * <blockquote><pre>
         * // Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
         * provider: CustomResourceProvider.fromTopic(myTopic)
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param provider The provider which implements the custom resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder provider(final software.amazon.awscdk.services.cloudformation.ICustomResourceProvider provider) {
            this.props.provider(provider);
            return this;
        }

        /**
         * (deprecated) Properties to pass to the Lambda.
         * <p>
         * Default: - No properties.
         * <p>
         * @return {@code this}
         * @param properties Properties to pass to the Lambda. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder properties(final java.util.Map<java.lang.String, ? extends java.lang.Object> properties) {
            this.props.properties(properties);
            return this;
        }

        /**
         * (deprecated) The policy to apply when this resource is removed from the application.
         * <p>
         * Default: cdk.RemovalPolicy.Destroy
         * <p>
         * @return {@code this}
         * @param removalPolicy The policy to apply when this resource is removed from the application. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder removalPolicy(final software.amazon.awscdk.core.RemovalPolicy removalPolicy) {
            this.props.removalPolicy(removalPolicy);
            return this;
        }

        /**
         * (deprecated) For custom resources, you can specify AWS::CloudFormation::CustomResource (the default) as the resource type, or you can specify your own resource type name.
         * <p>
         * For example, you can use "Custom::MyCustomResourceTypeName".
         * <p>
         * Custom resource type names must begin with "Custom::" and can include
         * alphanumeric characters and the following characters: _&#64;-. You can specify
         * a custom resource type name up to a maximum length of 60 characters. You
         * cannot change the type during an update.
         * <p>
         * Using your own resource type names helps you quickly differentiate the
         * types of custom resources in your stack. For example, if you had two custom
         * resources that conduct two different ping tests, you could name their type
         * as Custom::PingTester to make them easily identifiable as ping testers
         * (instead of using AWS::CloudFormation::CustomResource).
         * <p>
         * Default: - AWS::CloudFormation::CustomResource
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cfn-customresource.html#aws-cfn-resource-type-name
         * @param resourceType For custom resources, you can specify AWS::CloudFormation::CustomResource (the default) as the resource type, or you can specify your own resource type name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder resourceType(final java.lang.String resourceType) {
            this.props.resourceType(resourceType);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cloudformation.CustomResource}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.cloudformation.CustomResource build() {
            return new software.amazon.awscdk.services.cloudformation.CustomResource(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
